BUILD_BIT = '64bit'
BUILD_CPU = 'Intel(R) Core(TM) i7-6700K CPU @ 4.00GHz'
BUILD_DATE = '2025-01-14'
BUILD_MACHINE = 'x86_64'
BUILD_OS = 'Linux Fedora 41'
BUILD_TIME = '19:07'
BUILD_TYPE = ''
BUILT_BY = 'antoine'
BUILT_ON = 'fedora'
COMPILER_VERSION = 'gcc (GCC) 14.2.1 20240912 (Red Hat 14.2.1-3)'
CYTHON_VERSION = '3.0.11'
LINKER_VERSION = 'GNU ld version 2.43.1-5.fc41'
NVCC_VERSION = ''
PYTHON_VERSION = '3.13.1'
lib_gobjectintrospection10 = '1.82.0'
lib_gtk30 = '3.24.43'
lib_gtkx1130 = '3.24.43'
lib_nvenc = '12'
lib_nvfbc = '8.0'
lib_py3cairo = '1.20.1'
lib_pygobject30 = '3.42.2'
lib_python3 = '3.13'
lib_python_Cython = '3.0.11'
lib_python_PyGObject = '3.50.0'
lib_python_PyOpenGL = '3.1.8'
lib_python_PyOpenGLaccelerate = '3.1.8'
lib_python_pillow = '11.1.0'
lib_python_pycairo = '1.27.0'
lib_python_setuptools = '68.2.2'
lib_vpx = '1.14.1'
lib_x11 = '1.8.10'
lib_x264 = '0.164.3108'
lib_xcomposite = '0.4.6'
lib_xdamage = '1.1.6'
lib_xext = '1.3.6'
lib_xfixes = '6.0.1'
lib_xkbfile = '1.1.3'
lib_xrandr = '1.5.4'
lib_xtst = '1.2.5'
